@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2015 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,7 +30,7 @@ namespace gloox
    *
    * You should not need to use this class directly.
    *
-   * @author Jakob Schroeter <js@camaya.net>
+   * @author Jakob Schröter <js@camaya.net>
    * @since 0.9
    */
   class GLOOX_API ConnectionTCPServer : public ConnectionTCPBase
@@ -68,6 +68,9 @@ namespace gloox
     private:
       ConnectionTCPServer &operator=( const ConnectionTCPServer & );
 
+      // remove for 1.1
+      static int getSocket( int af, int socktype, int proto, const LogSink& logInstance );
+      
       ConnectionHandler* m_connectionHandler;
 
   };
